From 136762e82a9c4974c15b0525245092d11a825cee Mon Sep 17 00:00:00 2001
From: Shengjiu Wang <shengjiu.wang@freescale.com>
Date: Wed, 12 Jul 2017 18:00:58 +0800
Subject: [PATCH] MLK-15960-2: ASoC: fsl_sai: refine the pm runtime function

In imx8qm/imx8qxp, the power domain of IP is enabled when
pm_runtime_get_sync() is called, and disabled when pm_runtime
_put_sync() is called. when power domain is disabled, the value
of registers will lost, so we need to use the regcache_sync()
to restore the registers in fsl_sai_runtime_resume.

Signed-off-by: Shengjiu Wang <shengjiu.wang@freescale.com>
---
 sound/soc/fsl/fsl_sai.c | 4 ++++
 1 file changed, 4 insertions(+)

--- a/sound/soc/fsl/fsl_sai.c
+++ b/sound/soc/fsl/fsl_sai.c
@@ -1097,6 +1097,8 @@ static int fsl_sai_probe(struct platform
 
 	pm_runtime_enable(&pdev->dev);
 
+	regcache_cache_only(sai->regmap, true);
+
 	ret = devm_snd_soc_register_component(&pdev->dev, &fsl_component,
 					      &sai->cpu_dai_drv, 1);
 	if (ret)
@@ -1140,6 +1142,8 @@ static int fsl_sai_runtime_suspend(struc
 {
 	struct fsl_sai *sai = dev_get_drvdata(dev);
 
+	regcache_cache_only(sai->regmap, true);
+
 	if (sai->mclk_streams & BIT(SNDRV_PCM_STREAM_CAPTURE))
 		clk_disable_unprepare(sai->mclk_clk[sai->mclk_id[0]]);
 
